[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-09-11 Thread LLVM


Changes in directory llvm/utils:

NightlyTest.pl (r1.113) removed
---
Log message:

No longer used, and confuses maintainers

---
Diffs of the changes:  (+0 -0)

 0 files changed



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-06-28 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.111 -> 1.112
---
Log message:

Added -disable-cbe to disable C backend testing.

---
Diffs of the changes:  (+2 -0)

 NightlyTest.pl |2 ++
 1 files changed, 2 insertions(+)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.111 llvm/utils/NightlyTest.pl:1.112
--- llvm/utils/NightlyTest.pl:1.111 Tue Jun 27 15:30:28 2006
+++ llvm/utils/NightlyTest.pl   Wed Jun 28 19:54:37 2006
@@ -23,6 +23,7 @@
 #  -enable-llcbeta  Enable testing of beta features in llc.
 #  -disable-llc Disable LLC tests in the nightly tester.
 #  -disable-jit Disable JIT tests in the nightly tester.
+#  -disable-cbe Disable C backend tests in the nightly tester.
 #  -verbose Turn on some debug output
 #  -debug   Print information useful only to maintainers of this 
script.
 #  -niceCheckout/Configure/Build with "nice" to reduce impact 
@@ -303,6 +304,7 @@
  $CONFIGUREARGS .= " --disable-llc_diffs"; next; }
   if (/^-disable-jit$/){ $PROGTESTOPTS .= " DISABLE_JIT=1";
  $CONFIGUREARGS .= " --disable-jit"; next; }
+  if (/^-disable-cbe$/){ $PROGTESTOPTS .= " DISABLE_CBE=1"; next; }
   if (/^-verbose$/){ $VERBOSE = 1; next; }
   if (/^-debug$/)  { $DEBUG = 1; next; }
   if (/^-nice$/)   { $NICE = "nice "; next; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-06-27 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.110 -> 1.111
---
Log message:

Fix -extraflags

---
Diffs of the changes:  (+1 -1)

 NightlyTest.pl |2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.110 llvm/utils/NightlyTest.pl:1.111
--- llvm/utils/NightlyTest.pl:1.110 Tue Jun 20 13:49:13 2006
+++ llvm/utils/NightlyTest.pl   Tue Jun 27 15:30:28 2006
@@ -334,7 +334,7 @@
 $MAKEOPTS = "$MAKEOPTS $ARGV[0]"; shift; next;
   }
   if (/^-extraflags/)  {
-$PROGTESTOPTS .= " EXTRA_OPTIONS=\'$ARGV[0]\'"; shift; next;
+$CONFIGUREARGS .= " --with-extra-options=\'$ARGV[0]\'"; shift; next;
   }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-06-20 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.109 -> 1.110
---
Log message:

Rename EXTRA_FLAGS to EXTRA_OPTIONS.

---
Diffs of the changes:  (+1 -1)

 NightlyTest.pl |2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.109 llvm/utils/NightlyTest.pl:1.110
--- llvm/utils/NightlyTest.pl:1.109 Mon Jun 12 14:03:17 2006
+++ llvm/utils/NightlyTest.pl   Tue Jun 20 13:49:13 2006
@@ -334,7 +334,7 @@
 $MAKEOPTS = "$MAKEOPTS $ARGV[0]"; shift; next;
   }
   if (/^-extraflags/)  {
-$PROGTESTOPTS .= " EXTRA_FLAGS=\'$ARGV[0]\'"; shift; next;
+$PROGTESTOPTS .= " EXTRA_OPTIONS=\'$ARGV[0]\'"; shift; next;
   }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-06-12 Thread Chris Lattner


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.108 -> 1.109
---
Log message:

Add a new -compileflags options, remove old externals location specifiers.
People should just use -with-externals.


---
Diffs of the changes:  (+12 -25)

 NightlyTest.pl |   37 -
 1 files changed, 12 insertions(+), 25 deletions(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.107 llvm/utils/NightlyTest.pl:1.108
--- llvm/utils/NightlyTest.pl:1.107 Fri Apr 14 08:53:56 2006
+++ llvm/utils/NightlyTest.pl   Wed Jun  7 00:28:07 2006
@@ -43,6 +43,8 @@
 #   override the default.
 #  -ldflags Next argument specifies that linker options that override
 #   the default.
+#  -extraflags  Next argument specifies extra options that are passed to
+#   compile the tests.
 #
 #   Options to configure llvm-test 
 #  -spec2000pathPath to the benchspec directory in the SPEC 2000 distro
@@ -312,7 +314,7 @@
 $CONFIGUREARGS .= " --with-f2c=$ARGV[0]"; shift; next;
   }
   if (/^-with-externals/)  { 
-$CONFIGUREARGS .= "--with-externals=$ARGV[0]"; shift; next 
+$CONFIGUREARGS .= " --with-externals=$ARGV[0]"; shift; next 
   }
   if (/^-gnuplotscript$/)  { $PlotScriptFilename = $ARGV[0]; shift; next; }
   if (/^-templatefile$/)   { $Template = $ARGV[0]; shift; next; }
@@ -332,6 +334,9 @@
   if (/^-ldflags/) {
 $MAKEOPTS = "$MAKEOPTS LD.Flags=\'$ARGV[0]\'"; shift; next;
   }
+  if (/^-extraflags/) {
+$PROGTESTOPTS .= " EXTRA_FLAGS=\'$ARGV[0]\'"; shift; next;
+  }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }
   if (/^-spec2000path$/)   {



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-04-14 Thread Reid Spencer


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.106 -> 1.107
---
Log message:

Allow an option, -with-externals, to be specified that provides the location
of the external tests. This turns into --with-externals option to configure.


---
Diffs of the changes:  (+4 -0)

 NightlyTest.pl |4 
 1 files changed, 4 insertions(+)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.106 llvm/utils/NightlyTest.pl:1.107
--- llvm/utils/NightlyTest.pl:1.106 Mon Mar 20 19:21:39 2006
+++ llvm/utils/NightlyTest.pl   Fri Apr 14 08:53:56 2006
@@ -19,6 +19,7 @@
 #   LARGE_PROBLEM_SIZE enabled.
 #  -noexternals Do not run the external tests (for cases where povray
 #   or SPEC are not installed)
+#  -with-externals  Specify a directory where the external tests are located.
 #  -nodejagnu   Do not run feature or regression tests
 #  -parallelRun two parallel jobs with GNU Make.
 #  -release Build an LLVM Release version
@@ -310,6 +311,9 @@
   if (/^-f2c$/){
 $CONFIGUREARGS .= " --with-f2c=$ARGV[0]"; shift; next;
   }
+  if (/^-with-externals/)  { 
+$CONFIGUREARGS .= "--with-externals=$ARGV[0]"; shift; next 
+  }
   if (/^-gnuplotscript$/)  { $PlotScriptFilename = $ARGV[0]; shift; next; }
   if (/^-templatefile$/)   { $Template = $ARGV[0]; shift; next; }
   if (/^-gccpath/) { 



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-03-17 Thread Reid Spencer


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.104 -> 1.105
---
Log message:

Use the  tag instead of  tag to get code/file/warning lists to
wrap but also still be in a fixed-width font.


---
Diffs of the changes:  (+1 -1)

 NightlyTest.pl |2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.104 llvm/utils/NightlyTest.pl:1.105
--- llvm/utils/NightlyTest.pl:1.104 Wed Feb  8 03:08:06 2006
+++ llvm/utils/NightlyTest.pl   Fri Mar 17 11:43:01 2006
@@ -151,7 +151,7 @@
 
 sub AddPreTag {  # Add pre tags around nonempty list, or convert to "none"
   $_ = shift;
-  if (length) { return "$_"; } else { "none"; }
+  if (length) { return "$_"; } else { "none"; }
 }
 
 sub ChangeDir { # directory, logical name



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-02-08 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.103 -> 1.104
---
Log message:

Added options -cflag, -cxxflags, and -ldflags to override the default C
compilation, C++ compilation, and linker options.
e.g. This is the options I use for testing on my x86 iMac:
nice ./NightlyTest.pl -release -cflags "-Os -DNDEBUG -fomit-frame-pointer" 
-cxxflags "-Os -DNDEBUG -finline-functions -felide-constructors 
-fomit-frame-pointer"


---
Diffs of the changes:  (+15 -0)

 NightlyTest.pl |   15 +++
 1 files changed, 15 insertions(+)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.103 llvm/utils/NightlyTest.pl:1.104
--- llvm/utils/NightlyTest.pl:1.103 Wed Feb  8 01:28:22 2006
+++ llvm/utils/NightlyTest.pl   Wed Feb  8 03:08:06 2006
@@ -36,6 +36,12 @@
 #  -cvstag  Check out a specific CVS tag to build LLVM (useful for
 #   testing release branches)
 #  -target  Specify the target triplet
+#  -cflags  Next argument specifies that C compilation options that
+#   override the default.
+#  -cxxflagsNext argument specifies that C++ compilation options that
+#   override the default.
+#  -ldflags Next argument specifies that linker options that override
+#   the default.
 #
 #   Options to configure llvm-test 
 #  -spec2000pathPath to the benchspec directory in the SPEC 2000 distro
@@ -299,6 +305,15 @@
   if (/^-target/)  {
 $CONFIGUREARGS .= " --target=$ARGV[0]"; shift; next;
   }
+  if (/^-cflags/)  {
+$MAKEOPTS = "$MAKEOPTS C.Flags=\'$ARGV[0]\'"; shift; next;
+  }
+  if (/^-cxxflags/){
+$MAKEOPTS = "$MAKEOPTS CXX.Flags=\'$ARGV[0]\'"; shift; next;
+  }
+  if (/^-ldflags/) {
+$MAKEOPTS = "$MAKEOPTS LD.Flags=\'$ARGV[0]\'"; shift; next;
+  }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }
   if (/^-spec2000path$/)   {



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-02-07 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.102 -> 1.103
---
Log message:

Remove -pedantic. It no longer works.

---
Diffs of the changes:  (+0 -5)

 NightlyTest.pl |5 -
 1 files changed, 5 deletions(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.102 llvm/utils/NightlyTest.pl:1.103
--- llvm/utils/NightlyTest.pl:1.102 Tue Jan 31 10:10:53 2006
+++ llvm/utils/NightlyTest.pl   Wed Feb  8 01:28:22 2006
@@ -22,7 +22,6 @@
 #  -nodejagnu   Do not run feature or regression tests
 #  -parallelRun two parallel jobs with GNU Make.
 #  -release Build an LLVM Release version
-#  -pedanticEnable additional GCC warnings to detect possible errors.
 #  -enable-llcbeta  Enable testing of beta features in llc.
 #  -disable-llc Disable LLC tests in the nightly tester.
 #  -disable-jit Disable JIT tests in the nightly tester.
@@ -280,10 +279,6 @@
   if (/^-norunningtests$/) { $NORUNNINGTESTS = 1; next; }
   if (/^-parallel$/)   { $MAKEOPTS = "$MAKEOPTS -j2 -l3.0"; next; }
   if (/^-release$/){ $MAKEOPTS = "$MAKEOPTS ENABLE_OPTIMIZED=1"; next; 
}
-  if (/^-pedantic$/)   { 
-  $MAKEOPTS = "$MAKEOPTS CompileOptimizeOpts='-O3 -DNDEBUG 
-finline-functions -Wpointer-arith -Wcast-align -Wno-deprecated 
-Wold-style-cast -Wabi -Woverloaded-virtual -ffor-scope'"; 
-  next; 
-  }
   if (/^-enable-llcbeta$/) { $PROGTESTOPTS .= " ENABLE_LLCBETA=1"; next; }
   if (/^-disable-llc$/){ $PROGTESTOPTS .= " DISABLE_LLC=1";
  $CONFIGUREARGS .= " --disable-llc_diffs"; next; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-01-31 Thread Chris Lattner


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.101 -> 1.102
---
Log message:

solaris won't clobber an existing symlink with ln -sf apparently


---
Diffs of the changes:  (+4 -1)

 NightlyTest.pl |5 -
 1 files changed, 4 insertions(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.101 llvm/utils/NightlyTest.pl:1.102
--- llvm/utils/NightlyTest.pl:1.101 Sun Dec 11 13:55:39 2005
+++ llvm/utils/NightlyTest.pl   Tue Jan 31 10:10:53 2006
@@ -847,7 +847,10 @@
 my $TestPlatform = `uname -a`;
 eval "\$Output = 

[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2005-12-11 Thread Chris Lattner


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.100 -> 1.101
---
Log message:

Send an indicator to llvm-testresults if the build failed


---
Diffs of the changes:  (+1 -1)

 NightlyTest.pl |2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.100 llvm/utils/NightlyTest.pl:1.101
--- llvm/utils/NightlyTest.pl:1.100 Tue Nov  1 11:59:42 2005
+++ llvm/utils/NightlyTest.pl   Sun Dec 11 13:55:39 2005
@@ -462,7 +462,7 @@
   $BuildStatus = "error: compilation " .
 "aborted";
   $BuildError = 1;
-  if ($VERBOSE) { print "BUILD ERROR\n"; }
+  print "\n***ERROR BUILDING TREE\n\n";
 }
 
 if ($BuildError) { $NODEJAGNU=1; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2005-11-01 Thread Chris Lattner


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.99 -> 1.100
---
Log message:

Let people who run the nightly tester specify paths to external tests, instead
of having to hack the nightly tester script itself.

as an example, I use the following for my machine:

$HOME/llvm/utils/NightlyTest.pl -parallel -release -enable-llcbeta \
 -spec2000path 
/Volumes/ProjectsDisk/cvs/benchmarks/speccpu2000-llvm/benchspec/ \
 -povraypath /Volumes/ProjectsDisk/cvs/benchmarks/povray31 \
 -namdpath /Volumes/ProjectsDisk/cvs/benchmarks/namd



---
Diffs of the changes:  (+21 -2)

 NightlyTest.pl |   23 +--
 1 files changed, 21 insertions(+), 2 deletions(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.99 llvm/utils/NightlyTest.pl:1.100
--- llvm/utils/NightlyTest.pl:1.99  Sat Oct 29 12:01:41 2005
+++ llvm/utils/NightlyTest.pl   Tue Nov  1 11:59:42 2005
@@ -38,6 +38,12 @@
 #   testing release branches)
 #  -target  Specify the target triplet
 #
+#   Options to configure llvm-test 
+#  -spec2000pathPath to the benchspec directory in the SPEC 2000 distro
+#  -spec95path  Path to the benchspec directory in the SPEC 95 distro.
+#  -povraypath  Path to the povray sources
+#  -namdpathPath to the namd sources
+#
 # CVSROOT is the CVS repository from which the tree will be checked out,
 #  specified either in the full :method:[EMAIL PROTECTED]:/dir syntax, or
 #  just /dir if using a local repo.
@@ -86,6 +92,8 @@
 my $NICE = "";
 my $NODEJAGNU = 0;
 
+my $LLVMTESTCONFIGARGS = "";
+
 sub ReadFile {
   if (open (FILE, $_[0])) {
 undef $/;
@@ -298,7 +306,18 @@
   }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }
-
+  if (/^-spec2000path$/)   {
+$LLVMTESTCONFIGARGS .= " --enable-spec2000=$ARGV[0]"; shift; next;
+  }
+  if (/^-spec95path$/) {
+$LLVMTESTCONFIGARGS .= " --enable-spec95=$ARGV[0]"; shift; next;
+  }
+  if (/^-povraypath$/) {
+$LLVMTESTCONFIGARGS .= " --enable-povray=$ARGV[0]"; shift; next;
+  }
+  if (/^-namdpath$/)   {
+$LLVMTESTCONFIGARGS .= " --enable-namd=$ARGV[0]"; shift; next;
+  }
   print "Unknown option: $_ : ignoring!\n";
 }
 
@@ -410,7 +429,7 @@
 #
 if (!$NOCHECKOUT) {
   if ( $VERBOSE ) { print "CONFIGURE STAGE\n"; }
-  my $EXTRAFLAGS = "--enable-spec --with-objroot=.";
+  my $EXTRAFLAGS = "--enable-spec --with-objroot=.$LLVMTESTCONFIGARGS";
   system "(time -p $NICE ./configure $CONFIGUREARGS $EXTRAFLAGS) > $BuildLog 
2>&1";
 
   if ( $VERBOSE ) { print "BUILD STAGE\n"; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2005-10-29 Thread Chris Lattner


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.98 -> 1.99
---
Log message:

Revert an accidental commit.


---
Diffs of the changes:  (+1 -1)

 NightlyTest.pl |2 +-
 1 files changed, 1 insertion(+), 1 deletion(-)


Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.98 llvm/utils/NightlyTest.pl:1.99
--- llvm/utils/NightlyTest.pl:1.98  Fri Oct 28 11:35:18 2005
+++ llvm/utils/NightlyTest.pl   Sat Oct 29 12:01:41 2005
@@ -410,7 +410,7 @@
 #
 if (!$NOCHECKOUT) {
   if ( $VERBOSE ) { print "CONFIGURE STAGE\n"; }
-  my $EXTRAFLAGS = 
"--enable-spec2000=/Volumes/ProjectsDisk/cvs/benchmarks/speccpu2000-llvm/benchspec/
 --enable-povray=/Volumes/ProjectsDisk/cvs/benchmarks/povray31 
--enable-namd=/Volumes/ProjectsDisk/cvs/benchmarks/namd";
+  my $EXTRAFLAGS = "--enable-spec --with-objroot=.";
   system "(time -p $NICE ./configure $CONFIGUREARGS $EXTRAFLAGS) > $BuildLog 
2>&1";
 
   if ( $VERBOSE ) { print "BUILD STAGE\n"; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits
Index: llvm/utils/NightlyTest.pl
diff -u llvm/utils/NightlyTest.pl:1.108 llvm/utils/NightlyTest.pl:1.109
--- llvm/utils/NightlyTest.pl:1.108 Wed Jun  7 00:28:07 2006
+++ llvm/utils/NightlyTest.pl   Mon Jun 12 14:03:17 2006
@@ -17,9 +17,6 @@
 #   -norunningtests.
 #  -norunningtests  Do not run the Olden benchmark suite with
 #   LARGE_PROBLEM_SIZE enabled.
-#  -noexternals Do not run the external tests (for cases where povray
-#   or SPEC are not installed)
-#  -with-externals  Specify a directory where the external tests are located.
 #  -nodejagnu   Do not run feature or regression tests
 #  -parallelRun two parallel jobs with GNU Make.
 #  -release Build an LLVM Release version
@@ -43,14 +40,15 @@
 #   override the default.
 #  -ldflags Next argument specifies that linker options that override
 #   the default.
 #  -extraflags  Next argument specifies extra options that are passed to
 #   compile the tests.
 #
 #   Options to configure llvm-test 
-#  -spec2000pathPath to the benchspec directory in the SPEC 2000 distro
-#  -spec95path  Path to the benchspec directory in the SPEC 95 distro.
-#  -povraypath  Path to the povray sources
-#  -namdpathPath to the namd sources
+#  -extraflags  Next argument specifies extra options that are passed to
+#   compile the tests.
+#  -noexternals Do not run the external tests (for cases where povray
+#   or SPEC are not installed)
+#  -with-externals  Specify a directory where the external tests are located.
 #
 # CVSROOT is the CVS repository from which the tree will be checked out,
 #  specified either in the full :method:[EMAIL PROTECTED]:/dir syntax, or
@@ -100,8 +98,6 @@
 my $NICE = "";
 my $NODEJAGNU = 0;
 
-my $LLVMTESTCONFIGARGS = "";
-
 sub ReadFile {
   if (open (FILE, $_[0])) {
 undef $/;
@@ -334,23 +330,14 @@
   if (/^-ldflags/) {
 $MAKEOPTS = "$MAKEOPTS LD.Flags=\'$ARGV[0]\'"; shift; next;
   }
-  if (/^-extraflags/) {
+  if (/^-compileflags/){
+$MAKEOPTS = "$MAKEOPTS $ARGV[0]"; shift; next;
+  }
+  if (/^-extraflags/)  {
 $PROGTESTOPTS .= " EXTRA_FLAGS=\'$ARGV[0]\'"; shift; next;
   }
   if (/^-noexternals$/){ $NOEXTERNALS = 1; next; }
   if (/^-nodejagnu$/)  { $NODEJAGNU = 1; next; }
-  if (/^-spec2000path$/)   {
-$LLVMTESTCONFIGARGS .= " --enable-spec2000=$ARGV[0]"; shift; next;
-  }
-  if (/^-spec95path$/) {
-$LLVMTESTCONFIGARGS .= " --enable-spec95=$ARGV[0]"; shift; next;
-  }
-  if (/^-povraypath$/) {
-$LLVMTESTCONFIGARGS .= " --enable-povray=$ARGV[0]"; shift; next;
-  }
-  if (/^-namdpath$/)   {
-$LLVMTESTCONFIGARGS .= " --enable-namd=$ARGV[0]"; shift; next;
-  }
   print "Unknown option: $_ : ignoring!\n";
 }
 
@@ -462,7 +449,7 @@
 #
 if (!$NOCHECKOUT) {
   if ( $VERBOSE ) { print "CONFIGURE STAGE\n"; }
-  my $EXTRAFLAGS = "--enable-spec --with-objroot=.$LLVMTESTCONFIGARGS";
+  my $EXTRAFLAGS = "--enable-spec --with-objroot=.";
   system "(time -p $NICE ./configure $CONFIGUREARGS $EXTRAFLAGS) > $BuildLog 
2>&1";
 
   if ( $VERBOSE ) { print "BUILD STAGE\n"; }



___
llvm-commits mailing list
llvm-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-commits


[llvm-commits] CVS: llvm/utils/NightlyTest.pl

2006-06-06 Thread Evan Cheng


Changes in directory llvm/utils:

NightlyTest.pl updated: 1.107 -> 1.108
---
Log message:

Add -extraflags FLAGS to pass extra compilation options.

---
Diffs of the changes:  (+6 -1)

 NightlyTest.pl |7 ++-
@@ -43,14 +40,15 @@
 #  -ldflags Next argument specifies that linker options that override
 #   the default.
-#  -extraflags  Next argument specifies extra options that are passed to
-#   compile the tests.
+#  -compileflagsNext argument specifies extra options passed to make when
+#   building LLVM.
 #
 #   Options to configure llvm-test 
 1 files changed, 6 insertions(+), 1 deletion(-)

